package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table
 * <code>p2j_test.`vehicle_driver`</code> (previously
 * <code>p2j_test.vehicle-driver</code>).
 */
@LegacyTable(name = "vehicle-driver", table = "`vehicle_driver`")
@LegacyIndexes(
{
   @LegacyIndex(name = "pi-name", converted = "`vehicle_driver_pi_name`",  primary = true),
   @LegacyIndex(name = "si-vin", converted = "`vehicle_driver_si_vin`")
})
public class VehicleDriverImpl
implements Serializable,
           Persistable,
           VehicleDriver
{
   /** Surrogate primary key */
   private Long id = null;

   /** Name; Driver name */
   @LegacyField( fieldId = 1 , name = "name" , format = "x(32)" , label = "Name" , mandatory = true)
   private final character name;

   /** Age; Driver age */
   @LegacyField( fieldId = 2 , name = "age" , format = ">>9" , initial = "0" , label = "Age")
   private final integer age;

   /** VIN; Vehicle Identification Number */
   @LegacyField( fieldId = 3 , name = "vin-number" , format = "xxxx-xxxx-xxxx" , label = "VIN" , mandatory = true)
   private final character vinNumber;

   /**
    * Default constructor.
    */
   public VehicleDriverImpl()
   {
      name = new character("");
      age = new integer(0);
      vinNumber = new character("");
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new VehicleDriverImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      VehicleDriverImpl from = (VehicleDriverImpl) old;
      setId(from.getId());
      setName(from.getName());
      setAge(from.getAge());
      setVinNumber(from.getVinNumber());
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Driver name
    * 
    * @return  Name
    */
   public character getName()
   {
      return (new character(name));
   }

   /**
    * Setter: Driver name
    * 
    * @param   name
    *          Name
    */
   public void setName(Text name)
   {
      this.name.assign(name, true);
   }

   /**
    * Getter: Driver age
    * 
    * @return  Age
    */
   public integer getAge()
   {
      return (new integer(age));
   }

   /**
    * Setter: Driver age
    * 
    * @param   age
    *          Age
    */
   public void setAge(NumberType age)
   {
      this.age.assign(age, true);
   }

   /**
    * Getter: Vehicle Identification Number
    * 
    * @return  VIN
    */
   public character getVinNumber()
   {
      return (new character(vinNumber));
   }

   /**
    * Setter: Vehicle Identification Number
    * 
    * @param   vinNumber
    *          VIN
    */
   public void setVinNumber(Text vinNumber)
   {
      this.vinNumber.assign(vinNumber, true);
   }
}
